public inbox for isar-users@googlegroups.com
 help / color / mirror / Atom feed
From: "Maxim Yu. Osipov" <mosipov@ilbers.de>
To: isar-users@googlegroups.com
Subject: [PATCH 2/2] ci_build: Include cross build targets into default build
Date: Thu, 23 May 2019 07:27:47 +0200	[thread overview]
Message-ID: <20190523052747.2796-3-mosipov@ilbers.de> (raw)
In-Reply-To: <20190523052747.2796-1-mosipov@ilbers.de>

Signed-off-by: Maxim Yu. Osipov <mosipov@ilbers.de>
---
 scripts/ci_build.sh | 32 ++++++++++++++++++++------------
 1 file changed, 20 insertions(+), 12 deletions(-)

diff --git a/scripts/ci_build.sh b/scripts/ci_build.sh
index 7b4bb0e..314d9f2 100755
--- a/scripts/ci_build.sh
+++ b/scripts/ci_build.sh
@@ -35,6 +35,14 @@ TARGETS_SET="\
           # qemu-user-static of <= buster too old to build that
           # multiconfig:qemuarm64-buster:isar-image-base
 
+CROSS_TARGETS_SET="\
+                  multiconfig:qemuarm-stretch:isar-image-base \
+                  multiconfig:qemuarm-buster:isar-image-base \
+                  multiconfig:qemuarm64-stretch:isar-image-base \
+                  multiconfig:qemuamd64-stretch:isar-image-base \
+                  multiconfig:de0-nano-soc-stretch:isar-image-base \
+                  multiconfig:rpi-stretch:isar-image-base"
+
 REPRO_TARGETS_SET="\
             multiconfig:qemuarm-stretch:isar-image-base \
             multiconfig:qemuarm64-stretch:isar-image-base \
@@ -86,13 +94,6 @@ do
         # Enforce cross-compilation to speed up the build
         FAST_BUILD="1"
         CROSS_BUILD="1"
-        TARGETS_SET="\
-                     multiconfig:qemuarm-stretch:isar-image-base \
-                     multiconfig:qemuarm-buster:isar-image-base \
-                     multiconfig:qemuarm64-stretch:isar-image-base \
-                     multiconfig:qemuamd64-stretch:isar-image-base \
-                     multiconfig:de0-nano-soc-stretch:isar-image-base \
-                     multiconfig:rpi-stretch:isar-image-base"
         ;;
     -q|--quiet)
         BB_ARGS=""
@@ -132,12 +133,19 @@ if [ -n "$REPRO_BUILD" ]; then
     sed -i -e 's/ISAR_USE_CACHED_BASE_REPO ?= "1"/#ISAR_USE_CACHED_BASE_REPO ?= "1"/g' conf/local.conf
 fi
 
-# Start build for the defined set of configurations
-bitbake $BB_ARGS $TARGETS_SET
-
+# Start cross build for the defined set of configurations
+sed -i -e 's/ISAR_CROSS_COMPILE ?= "0"/ISAR_CROSS_COMPILE ?= "1"/g' conf/local.conf
+bitbake $BB_ARGS $CROSS_TARGETS_SET
+while [ -e bitbake.sock ]; do sleep 1; done
 # In addition test SDK creation
-if [ -n "$FAST_BUILD" ]; then
-    bitbake $BB_ARGS -c do_populate_sdk multiconfig:qemuarm-stretch:isar-image-base
+bitbake $BB_ARGS -c do_populate_sdk multiconfig:qemuarm-stretch:isar-image-base
+while [ -e bitbake.sock ]; do sleep 1; done
+
+if [ ! -n "$FAST_BUILD" ]; then
+    # Cleanup and disable cross build
+    sudo rm -rf tmp
+    sed -i -e 's/ISAR_CROSS_COMPILE ?= "1"/ISAR_CROSS_COMPILE ?= "0"/g' conf/local.conf
+    bitbake $BB_ARGS $TARGETS_SET
 fi
 
 cp -a "${ISARROOT}/meta/classes/dpkg-base.bbclass" "${ISARROOT}/meta/classes/dpkg-base.bbclass.ci-backup"
-- 
2.11.0


  parent reply	other threads:[~2019-05-23  5:28 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-05-23  5:27 [PATCH 0/2] CI build improvements Maxim Yu. Osipov
2019-05-23  5:27 ` [PATCH 1/2] ci_build: Write each command to standard error Maxim Yu. Osipov
2019-05-23 12:35   ` Claudius Heine
2019-05-23 13:15     ` Maxim Yu. Osipov
2019-05-23  5:27 ` Maxim Yu. Osipov [this message]
2019-05-24 13:07 ` [PATCH 0/2] CI build improvements Maxim Yu. Osipov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20190523052747.2796-3-mosipov@ilbers.de \
    --to=mosipov@ilbers.de \
    --cc=isar-users@googlegroups.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox